---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug, help wanted
assignees: dbdimitrov

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
If possible please provide a minimal reproducible example.
For example, a downsampled version of the your `anndata` object.

**Screenshots**
If applicable, add screenshots with a traceback to any exception.
